@@ -9,6 +9,7 @@ from sqlalchemy.pool import SingletonThreadPool
 from clusto import drivers
 
 import threading
+import logging.config
 import logging
 import time
 import re
@@ -38,7 +39,26 @@ def connect(config, echo=False):
     if config.has_option('clusto', 'versioning'):
         SESSION.clusto_versioning_enabled = config.getboolean('clusto', 'versioning')
     else:
-        SESSION.clusto_versioning_enabled = True
+        SESSION.clusto_versioning_enabled = False
+
+    # Set the log level from config, default is WARNING
+    if config.has_option('clusto', 'loglevel'):
+        rootlog = logging.getLogger()
+        level = logging.getLevelName(config.get('clusto', 'loglevel'))
+        rootlog.setLevel(level)
+
+    # Setup audit logging to a file
+    if config.has_option('clusto', 'auditlog'):
+        auditlog = logging.getLogger('clusto.audit')
+        auditlog.propagate = False
+        auditlog.setLevel(logging.INFO)
+        logfile = config.get('clusto', 'auditlog')
+        handler = logging.handlers.WatchedFileHandler(logfile)
+        handler.setFormatter(logging.Formatter(
+            '%(asctime)s %(name)s %(levelname)s %(message)s',
+            '%Y-%m-%d %H:%M:%S'
+        ))
+        auditlog.addHandler(handler)
 
     try:
         memcache_servers = config.get('clusto', 'memcached').split(',')
@@ -152,7 +172,7 @@ def get_entities(names=(), clusto_types=(), clusto_drivers=(), attrs=()):
 
     if attrs:
         for k,v in attrs[0].items():
-            if not isinstance(v,str):
+            if not isinstance(v, basestring):
                 continue
             attrs[0][k] = u'%s' % v
         query = query.filter(Attribute.entity_id==Entity.entity_id)
