@@ -13,6 +13,7 @@ from sqlalchemy.orm import scoped_session, sessionmaker, mapper, relation
 
 import sqlalchemy.sql
 
+import logging
 import sys
 import datetime
 import clusto
@@ -42,6 +43,9 @@ CLUSTO_VERSIONING = Table('clustoversioning', METADATA,
 
                           )
 
+logging.basicConfig(format='%(asctime)s %(name)s %(levelname)s %(message)s')
+audit_log = logging.getLogger('clusto.audit')
+
 class ClustoEmptyCommit(Exception):
     pass
 
@@ -164,6 +168,8 @@ class Counter(object):
 
         self.value = start
 
+        audit_log.info('create counter entity=%s attr_key=%s value=%s', self.entity.name, self.attr_key, self.value)
+
         SESSION.add(self)
         SESSION.flush()
 
@@ -171,6 +177,7 @@ class Counter(object):
 
         self.value = Counter.value + 1
         SESSION.flush()
+        audit_log.info('increment counter entity=%s attr_key=%s value=%s', self.entity.name, self.attr_key, self.value)
         return self.value
 
     @classmethod
@@ -250,6 +257,8 @@ class Attribute(ProtectedObj):
             self.number = number
 
 
+        audit_log.info('create attribute entity=%s key=%s subkey=%s value=%s number=%s datatype=%s',
+                self.entity.name, self.key, self.subkey, self.value, self.number, self.datatype)
         SESSION.add(self)
         SESSION.flush()
 
@@ -369,13 +378,21 @@ class Attribute(ProtectedObj):
         
         setattr(self, value_type, value)
 
+        audit_log.info('set attribute entity=%s key=%s subkey=%s value=%s number=%s datatype=%s',
+                self.entity.name, self.key, self.subkey, self.value, self.number, self.datatype)
+
     value = property(_get_value, _set_value)
 
     @ProtectedObj.writer
     def delete(self):
         ### TODO this seems like a hack
-
-        self.deleted_at_version = working_version()
+        audit_log.info('delete attribute entity=%s key=%s subkey=%s value=%s number=%s datatype=%s',
+                self.entity.name, self.key, self.subkey, self.value, self.number, self.datatype)
+        if SESSION.clusto_versioning_enabled:
+            self.deleted_at_version = working_version()
+        else:
+            SESSION.delete(self)
+            SESSION.flush()
 
     @classmethod
     def _version_args(cls):
@@ -462,6 +479,9 @@ class Entity(ProtectedObj):
         self.type = clustotype
 
         self.version = working_version()
+
+        audit_log.info('create entity %s driver=%s type=%s', self.name, self.driver, self.type)
+
         SESSION.add(self)
         SESSION.flush()
 
@@ -520,15 +540,20 @@ class Entity(ProtectedObj):
 
         clusto.begin_transaction()
         try:
-            self.deleted_at_version = working_version()
-
             for i in self.references:
                 i.delete()
 
             for i in self.attrs:
                 i.delete()
 
+            if SESSION.clusto_versioning_enabled:
+                self.deleted_at_version = working_version()
+            else:
+                SESSION.delete(self)
+                SESSION.flush()
+
             clusto.commit()
+            audit_log.info('delete entity %s', self.name)
         except Exception, x:
             clusto.rollback_transaction()
             raise x
